2022-11-16 Version: 2.2.11
- Add ImportOAS.

2022-11-03 Version: 2.2.10
- Add QueryRequestLogs.

2022-10-13 Version: 2.2.9
- Add DatasetMethods.

2022-09-09 Version: 2.2.8
- Update SetDomainWebSocketStatus.

2022-09-02 Version: 2.2.7
- Add input parameters of DescribeApps and DescribeDeployedApis.

2022-08-29 Version: 2.2.6
- Modify  Api Ram-Meta.

2022-08-01 Version: 2.2.5
- Add parameter stageName for BatchAbolishApis.

2022-07-18 Version: 2.2.4
- Change the parameter tag to optional.

2022-07-15 Version: 2.2.3
- Add param ModifyAction.

2022-06-29 Version: 2.2.1
- Add an input param, IsHttpRedirectToHttps, of api, SetDomain.

2022-06-24 Version: 2.2.0
- Add apis for access control of instance.

2022-06-16 Version: 2.1.7
- Add response paramof api DescribeInstances.

2022-05-08 Version: 2.1.6
- Add parameter of api SetDomainCertificate.

2022-04-28 Version: 2.1.5
- Add a new api ModifyApiConfiguration.

2022-04-16 Version: 2.1.4
- Support customized host header in vpc access.

2022-03-22 Version: 2.1.3
- Support the new backend service, EventBridge.

2022-03-17 Version: 2.1.2
- Add api DetachPlugin.

2022-03-03 Version: 2.1.1
- DescribeApisByVpcAccess adds path and method of API in result.

2022-01-24 Version: 2.1.0
- Add apis for creating API by using backend service.

2021-12-31 Version: 2.0.3
- Update response parameter in DescribePlugins.
- Add query parameter vpcId, instanceId, port in DescribeVpcAccesses.

2021-12-08 Version: 2.0.2
- Add parameters in ImportSwagger and DryRun.

2021-11-23 Version: 2.0.0
- Update DescribeApisByApp.

2021-10-26 Version: 1.0.0
- Create SDK after migrating from POP to apm.

